==> digikam_5.3.0.orig.tar.xz: digikam-5.3.0/extra/kipi-plugins/googleservices/kipiplugin_googleservices.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Google Services
Name=Google Services
Name[ca]=Google Services
Name[ca@valencia]=Google Services
Name[cs]=Služby Google
Name[da]=Google-tjenester
Name[de]=Google Services
Name[el]=Google Services
Name[en_GB]=Google Services
Name[es]=Servicios de Google
Name[fi]=Google Services
Name[fr]=Services Google
Name[gl]=Servizos de Google
Name[is]=Google þjónustur
Name[it]=Servizi di Google
Name[ko]=Google 서비스
Name[nl]=Google Services
Name[pl]=Usługi Google
Name[pt]=Serviços do Google
Name[pt_BR]=Serviços do Google
Name[sk]=Google služby
Name[sl]=Storitve Google
Name[sv]=Google-tjänster
Name[uk]=Служби Google
Name[x-test]=xxGoogle Servicesxx
Comment=A tool to manage images with a remote Google web service
Comment[ca]=Una eina per gestionar imatges amb el servei web remot de Google
Comment[ca@valencia]=Una eina per gestionar imatges amb el servei web remot de Google
Comment[cs]=Nástroj pro správu obrázků vzdálené webové služby Google
Comment[da]=Et værktøj til at håndtere billeder med en ekstern webbaseret Google-tjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Google-Webdienst zu verwalten.
Comment[el]=Εργαλείο διαχείρισης εικόνων σε μια απομακρυσμένη υπηρεσία ιστού της Google
Comment[en_GB]=A tool to manage images with a remote Google web service
Comment[es]=Una herramienta para la gestión de imágenes con un servicio remoto de Google
Comment[fi]=Työkalu kuvien hallitsemiseen Googlen verkkopalvelulla
Comment[fr]=Outil d'export d'images vers un service web Google
Comment[gl]=Unha ferramenta para xestionar imaxes cun servizo web de Google remoto.
Comment[is]=Verkfæri til að sýsla með myndir á fjartengdri Google vefþjónustu
Comment[it]=Uno strumento per gestire immagini con un servizio Web remoto di Google
Comment[ko]=원격 Google 웹 서비스의 사진을 관리하는 도구
Comment[nl]=Een hulpmiddel om afbeeldingen met een Google Services-webservice te beheren
Comment[pl]=Narzędzie do zarządzania obrazami przy użyciu zdalnej usługi sieciowej Google
Comment[pt]=Uma ferramenta para gerir imagens com um dos serviços Web remotos da Google
Comment[pt_BR]=Ferramenta para gerenciar imagens com os serviços do Google
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu webovú Google
Comment[sl]=Orodje za upravljanje slik z oddaljeno spletno storitvijo Google
Comment[sv]=Ett verktyg för att hantera bilder med en Google webbtjänst
Comment[uk]=Інструмент для керування зображеннями за допомогою віддаленої служби Google
Comment[x-test]=xxA tool to manage images with a remote Google web servicexx
Type=Service
Icon=kipi-googledrive
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_googleservices
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com

==> digikam_5.6.0.orig.tar.xz: digikam-5.6.0/extra/kipi-plugins/googleservices/kipiplugin_googleservices.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Google Services
Name=Google Services
Name[ca]=Google Services
Name[ca@valencia]=Google Services
Name[cs]=Služby Google
Name[da]=Google-tjenester
Name[de]=Google Services
Name[el]=Google Services
Name[en_GB]=Google Services
Name[es]=Servicios de Google
Name[fi]=Google Services
Name[fr]=Services Google
Name[gl]=Servizos de Google
Name[is]=Google þjónustur
Name[it]=Servizi di Google
Name[ko]=Google 서비스
Name[nl]=Google Services
Name[pl]=Usługi Google
Name[pt]=Serviços do Google
Name[pt_BR]=Serviços do Google
Name[sk]=Google služby
Name[sl]=Storitve Google
Name[sv]=Google-tjänster
Name[tr]=Google Servisleri
Name[uk]=Служби Google
Name[x-test]=xxGoogle Servicesxx
Comment=A tool to manage images with a remote Google web service
Comment[ca]=Una eina per gestionar imatges amb el servei web remot de Google
Comment[ca@valencia]=Una eina per gestionar imatges amb el servei web remot de Google
Comment[cs]=Nástroj pro správu obrázků vzdálené webové služby Google
Comment[da]=Et værktøj til at håndtere billeder med en ekstern webbaseret Google-tjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Google-Webdienst zu verwalten.
Comment[el]=Εργαλείο διαχείρισης εικόνων σε μια απομακρυσμένη υπηρεσία ιστού της Google
Comment[en_GB]=A tool to manage images with a remote Google web service
Comment[es]=Una herramienta para la gestión de imágenes con un servicio remoto de Google
Comment[fi]=Työkalu kuvien hallitsemiseen Googlen verkkopalvelulla
Comment[fr]=Outil d'export d'images vers un service web Google
Comment[gl]=Unha ferramenta para xestionar imaxes cun servizo web de Google remoto.
Comment[is]=Verkfæri til að sýsla með myndir á fjartengdri Google vefþjónustu
Comment[it]=Uno strumento per gestire immagini con un servizio Web remoto di Google
Comment[ko]=원격 Google 웹 서비스의 사진을 관리하는 도구
Comment[nl]=Een hulpmiddel om afbeeldingen met een Google Services-webservice te beheren
Comment[pl]=Narzędzie do zarządzania obrazami przy użyciu zdalnej usługi sieciowej Google
Comment[pt]=Uma ferramenta para gerir imagens com um dos serviços Web remotos da Google
Comment[pt_BR]=Ferramenta para gerenciar imagens com os serviços do Google
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu webovú Google
Comment[sl]=Orodje za upravljanje slik z oddaljeno spletno storitvijo Google
Comment[sv]=Ett verktyg för att hantera bilder med en Google webbtjänst
Comment[tr]=Resimleri uzak bir Google Drive web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для керування зображеннями за допомогою віддаленої служби Google
Comment[x-test]=xxA tool to manage images with a remote Google web servicexx
Type=Service
Icon=kipi-googledrive
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_googleservices
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com
